% CTA_demo2.m
% CTA_demo2.m demonstrates a standard group analysis pipeline
% for 2 different groups (i.e., diseased vs. controls)

clear;
close all;

load demo2_surf.mat;    % load a sample brain surface and atrophy regions

n1 = 20;    % number of subjects in group1
n2 = 20;    % number of subjects in group2

N = length(surf.vertices);
%% Ground truth
p_truth1 = tr1;
p_truth2 = tr2;
p_truth = [tr1;tr2];

f_truth = zeros(N,1);
f_truth(p_truth1) = 1;
f_truth(p_truth2) = 2;

figure;CTA_draw_surf(surf, f_truth);  % plot the ground truth
title('ground truth');

%% Generating synthetic cortical thickness and atrophy
for i=1:n1
    f1{i} = normrnd(2,0.1,[N,1]);
    f1{i}(p_truth1) = f1{i}(p_truth1) - normrnd(0.2,0.01,[length(p_truth1),1]);
    f1{i}(p_truth2) = f1{i}(p_truth2) - normrnd(0.4,0.02,[length(p_truth2),1]);    
    f1{i} = f1{i} + normrnd(0,1,[N,1]);
end

for i=1:n2
    f2{i} = normrnd(2,0.1,[N,1]);
    f2{i} = f2{i} + normrnd(0,1,[N,1]);
end

%% smoothing parameter setting
m = 50;
alph = 1;
tol = 1e-3;

%% WMD parameter setting
m2 = 10;
K2 = 20;
%alph = 1;
designtype = 'abspline3'; % wavelet type
J2 = 5; % number of scales

lmax = 18.5;
arange = [0 lmax];

[g,t]=sgwt_filter_design(lmax,J2,'designtype',designtype,'lpfactor',K2);

c = cell(numel(g),1);
for k=1:numel(g)
    c{k}=sgwt_cheby_coeff(g{k},m,m+1,arange);
end

%% Smoothing & WMD
A = triangulation2adjacency(surf.faces, surf.vertices);
[D, L] = CTA_spectralgraph(A); 

for i=1:n1   
    % smoothing    
    fs1{i} = CTA_heat_smoothing(f1{i}, L, alph, m, tol);   
    
    % WMD    
    WMD1{i} = sgwt_cheby_op(f1{i},L,c,arange);        
end

for i=1:n2   
    % smoothing    
    fs2{i} = CTA_heat_smoothing(f2{i}, L, alph, m, tol);   
    
    % WMD    
    WMD2{i} = sgwt_cheby_op(f2{i},L,c,arange);        
end

%% t-test on the raw data and the result after multiple comparison correction
group1 = cell2mat(f1);
group2 = cell2mat(f2);

[h p_raw] = ttest2(group1', group2');

q = 0.05;   % FDR
[p_sort_raw, idx, max_k, fdr, thr] = FDR(p_raw, q);

p_raw_corrected = p_raw;
p_raw_corrected(p_raw_corrected>thr) = 1; % set all p-values above threshold to 1
figure;CTA_draw_surf(surf, -log10(p_raw_corrected));%colormap jet;


%% t-test on the smoothed data and the result after multiple comparison correction
group1 = cell2mat(fs1);
group2 = cell2mat(fs2);
[h, p_smth] = ttest2(group1', group2');
[p_sort_smth, idx, max_k, fdr, thr] = FDR(p_smth, q);

p_smth_corrected = p_smth;
p_smth_corrected(p_smth_corrected>thr) = 1;
figure;CTA_draw_surf(surf, -log10(p_smth_corrected));%colormap jet;


%% Hoteling's T2 test on WMD and the result after multiple comparison correction
clear group1 group2;
for i=1:n1
    group1(:,:,i) = reshape(cell2mat(WMD1{i}), [], J2+1);
    group2(:,:,i) = reshape(cell2mat(WMD2{i}), [], J2+1);
end

d = 1:J2-2 % selected scales for multi-variate hypothesis testing

[h p_wmd] = hotelT2(group1(:,d,:), group2(:,d,:)); 
[p_sort_wmd, idx, max_k, fdr, thr] = FDR(p_wmd, q);

p_wmd_corrected = p_wmd;
p_wmd_corrected(p_wmd_corrected>thr) = 1;
figure;CTA_draw_surf(surf, -log10(p_wmd_corrected));caxis([0 6])%colormap jet;

%% plot FDR threshold and sorted p-values
figure;
plot(-log10(p_sort_wmd), 'Linewidth',2);hold on;
plot(-log10(p_sort_raw), 'g','Linewidth',2);
plot(-log10(p_sort_smth), 'y','Linewidth',2);
plot(-log10(fdr),'r--', 'Linewidth',2);
grid on;
legend('sorted p-values (WMD)','sorted p-values (raw)', 'sorted p-values (smth)', 'FDR 0.05');
xlabel('index');
ylabel('-log10 p');
set(gca,'Position',[0.09 0.09 0.88 0.88])
